
# BMCS Shells

## Installation

### Dependencies

Dependencies on `gmsh` and `pygmsh` included in `environment.yml` 
Anaconda versioning seems not up to date.

Problem with dependencies in `pyface` with a missing 
dependency on `anaconda` cloud. As a fix,`importlib-resources`
that was reported as missing has been included in environment.

